import { component, h } from 'rocky7';
import { EditorView, basicSetup } from 'codemirror';
import { javascript } from '@codemirror/lang-javascript';

function styleInject(css, ref) {
  if ( ref === void 0 ) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') { return; }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css_248z = ".Layout-module_container__nOaUb {\n  position: absolute;\n  width: 100%;\n  height: 100%;\n  overflow: auto;\n  background: white;\n}\n.Layout-module_container__nOaUb > iframe {\n  height: 100%;\n  border: none;\n}";
var styles = {"container":"Layout-module_container__nOaUb"};
styleInject(css_248z);

/** @jsx h **/
const setupCodemirror = (el) => {
    console.log(el);
    console.log(el.contentDocument, el.contentDocument?.body);
    el.contentDocument.body.innerHTML = `<style>
      html, body { margin: 0; padding: 0; height: 100vh; }
      #codemirrorContainer {
        height: 100vh;
      }
      #codemirrorContainer > div {
        height: 100vh;
      }
      </style>
      <div id="codemirrorContainer"></div>
      `;
    let editor = new EditorView({
        extensions: [basicSetup, javascript()],
        parent: el.contentDocument?.querySelector("#codemirrorContainer"),
    });
    return editor;
};
const Layout = component("Layout", (props, utils) => {
    let container;
    return (h("iframe", { frameBorder: "none", ref: (el) => {
            container = el;
        }, onLoad: () => {
            if (container) {
                setupCodemirror(container);
            }
        }, class: styles.container }));
});

/** @jsx h **/
const Application = component("Bodhi", (props, utils) => {
    return (h("div", null,
        h(Layout, null)));
});

export { Application };
